import sys

def reducer():
    yearly_min = {}  
    
    for line in sys.stdin:
        line = line.strip()
        if not line:
            continue
        try:
            year, temp, _ = line.split('\t')
            temp = float(temp)
            if year in yearly_min:
                if temp < yearly_min[year]:
                    yearly_min[year] = temp
            else:
                yearly_min[year] = temp
                
        except ValueError:
            continue
    coolest_year = None
    coolest_temp = float('inf')
    for year, temp in yearly_min.items():
        if temp < coolest_temp:
            coolest_temp = temp
            coolest_year = year
    
    if coolest_year:
        print("coolest year ",str(coolest_year),"  Minimum Temperature ",str(coolest_temp))

if __name__ == "__main__":
    reducer()


import sys

current_bigram = None
current_count = 0

for line in sys.stdin:
    bigram, count = line.strip().split('\t')
    count = int(count)

    if current_bigram == bigram:
        current_count += count
    else:
        if current_bigram:
            print '%-40s\t%s' % (current_bigram, current_count)
        current_bigram = bigram
        current_count = count

if current_bigram:
    print '%-40s\t%s' % (current_bigram, current_count)


import sys

d = 0.85
try:
    N = int(sys.argv[1]) if len(sys.argv) > 1 else 4
except:
    N = 4

teleport = (1.0 - d) / float(N)
current = None
adj = ""
rank_sum = 0.0
for raw in sys.stdin:
    line = raw.strip()
    if not line:
        continue
    parts = line.split('\t', 1)
    if len(parts) != 2:
        continue
    node, val = parts[0].strip(), parts[1].strip()
    if current is None:
        current = node
    if node != current:
        new_rank = teleport + d * rank_sum
        print "%s\t%s\t%f" % (current, adj, new_rank)
        current = node
        adj = ""
        rank_sum = 0.0
    try:
        contrib = float(val)
        rank_sum += contrib
    except ValueError:
        adj = val

if current is not None:
    new_rank = teleport + d * rank_sum
    print "%s\t%s\t%f" % (current, adj, new_rank)


import sys

for line in sys.stdin:
    line = line.strip().lower()
    for p in [".", ",", "!", "?", "'", '"']:
        line = line.replace(p, "")
    words = line.split()

    for i in range(len(words) - 1):
        bigram = words[i] + " " + words[i+1]
        print '%-40s\t%s' % (bigram, 1)



#usr/bin/env python

import sys

line= sys.stdin

for row in sys.stdin:
	row=row.strip().split(',')
	if len(row) > 7 :
		user_name = row[7].strip()
		binary = str(bin(abs(hash(user_name))))[2:]
		t_zeros = len(binary) - len(binary.rstrip('0'))
		print('%d' % t_zeros)




import sys

for line in sys.stdin:
    line = line.strip().lower()
    for p in [".", ",", "!", "?", "'", '"']:
        line = line.replace(p, "")

    words = line.split()
    for word in words:
        print '%-20s %s' % (word, 1)



import sys

for raw in sys.stdin:
    line = raw.strip()
    if not line:
        continue
    parts = line.split('\t')
    if len(parts) < 2:
        parts = line.split(None, 2)
    node = None; links = ""; rank_str = None
    if len(parts) == 3:
        node = parts[0].strip()
        links = parts[1].strip()
        rank_str = parts[2].strip()
    elif len(parts) == 2:
        node = parts[0].strip()
        links = parts[1].strip()
        rank_str = None
    else:
        continue
    if rank_str in (None, ""):
        rank = 0.25
    else:
        try:
            rank = float(rank_str)
        except:
            if '/' in rank_str:
                try:
                    num, den = rank_str.split('/', 1)
                    rank = float(num) / float(den)
                except:
                    rank = 0.0
            else:
                rank = 0.0
    outlinks = [s.strip() for s in links.split(',') if s.strip() != ""]
    if outlinks:
        share = rank / len(outlinks)
        for tgt in outlinks:
            print "%s\t%f" % (tgt, share)
    print "%s\t%s" % (node, links)


import sys

current_word = None
current_count = 0

for line in sys.stdin:
    word, count = line.strip().split()
    count = int(count)

    if current_word == word:
        current_count += count
    else:
        if current_word:
            print '%-20s %s' % (current_word, current_count)
        current_word = word
        current_count = count

if current_word:
    print '%-20s %s' % (current_word, current_count)


import math

class BloomFilter:
    def __init__(self, size=13):
        self.size = size
        self.bit_array = [0] * size
       
    def h1(self, x):
        return (2*x) % self.size
      
    def h2(self, x):
        return (x+10) % self.size
       
    def h3(self, x):
        return (x + 15) % self.size
       
    def add(self, element, hash_count):
        positions = []
        collisions = 0
	if hash_count >= 1:
            positions.append(self.h1(element))
        if hash_count >= 2:
            positions.append(self.h2(element))
        if hash_count >= 3:
            positions.append(self.h3(element))
           
        for pos in positions:
            if self.bit_array[pos] == 1:
                collisions += 1
            self.bit_array[pos] = 1
        return collisions
       
    def count_ones(self):
        return sum(self.bit_array)
def calculate_error_rate(x, y, z):
    return (1 - math.exp(-z * y / x)) ** z

def main():
    # Input parameters
    y = 13  # Number of bits in array
    elements = [142,87,95,153]
    x = len(elements)  # Number of elements
   
    print "Number of Elements (x):\t%d" % x
    print "Bit Array Size (y):\t%d\n" % y
   
    optimal_z = 1
    min_error = 1.0  # Initialize with maximum possible error
    for z in [1, 2, 3]:  # Test 1, 2, and 3 hash functions
        bf = BloomFilter(y)
        total_collisions = 0
       
        for element in elements:
            total_collisions += bf.add(element, z)
       
        ones = bf.count_ones()
        error = calculate_error_rate(x, y, z)
	print "Case %d: Using %d hash function(s)" % (z, z)
        print "Collisions:\t%d" % total_collisions
        print "Ones in array:\t%d/%d" % (ones, y)
        print "Error rate:\t%.4f" % error
        print "Bit array:\t%s\n" % bf.bit_array
	if error < min_error:
            min_error = error
            optimal_z = z
   
    print "Optimal number of hash functions: %d" % optimal_z
    print "Minimum error rate achieved: %.4f" % min_error

if __name__ == "__main__":
    main()



#usr/bin/env python
import sys

max_trail = 0
for line in sys.stdin :
	line = line.strip()
	if not line : continue
	try :
		trail = int(line)
		if max_trail < trail :
			max_trail = trail
	except : continue
else:
	print("Total number of unique uids are : ",2**max_trail)



import sys
from datetime import datetime
i = 0
for line in sys.stdin:
    if 1-i:
        i+=1
        continue
    line = line.strip().split(',')
    date = line[1].split('-')
    date = datetime(int(date[0]), int(date[1]), int(date[2]))
    temp = float(line[2])
    if not line:
        continue
        
    try:
         year = date.year
         temp = float(temp)
         print str(year)+ "\t" +str(temp)+ "\t"+str(1)
    except ValueError:
         continue
